// @ts-check

/**
  Kitten Icons

  This is a subset of the Phosphor icons set, version 2.1.1
  (https://phosphoricons.com) by Helena Zhang and Tobias Fried in Kitten
  component format with some modifications to make it compatible with the
  Small Techonology Principles (https://small-tech.org/about/small-tech).

  Specifically:

    - Removes icons from Big Tech/Silicon Valley/surveillance capitalists/people farmers.
    - Removes BTC (proof of work cryptocurrency).
    - Renames user to person and users to people. (We do not have users in Small Tech and
      the Small Web; we have people and we treat them as such.)

  Also, creates `categories` and `tags` object hierarchies based on
  metadata provided in the library to make it easier to discover icons
  during authoring.
*/

import { catalog } from './catalog/index.mjs'
import { categories } from './catalog/categories.mjs'
import { tags } from './catalog/tags.mjs'

/** @type {catalog & {categories: categories, tags: tags} } */
const icons = Object.assign(catalog, { categories, tags })

export { icons }
